@@ -353,13 +353,13 @@ PyAPI_FUNC(Signed) PyInt_AsLong(struct _object *arg0);
 #define PyInt_AsSsize_t PyPyInt_AsSsize_t
 PyAPI_FUNC(Signed) PyInt_AsSsize_t(struct _object *arg0);
 #define PyInt_AsUnsignedLong PyPyInt_AsUnsignedLong
-PyAPI_FUNC(Unsigned) PyInt_AsUnsignedLong(struct _object *arg0);
+PyAPI_FUNC(size_t) PyInt_AsUnsignedLong(struct _object *arg0);
 #define PyInt_AsUnsignedLongLongMask PyPyInt_AsUnsignedLongLongMask
-PyAPI_FUNC(Unsigned) PyInt_AsUnsignedLongLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyInt_AsUnsignedLongLongMask(struct _object *arg0);
 #define PyInt_AsUnsignedLongMask PyPyInt_AsUnsignedLongMask
-PyAPI_FUNC(Unsigned) PyInt_AsUnsignedLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyInt_AsUnsignedLongMask(struct _object *arg0);
 #define PyInt_FromSize_t PyPyInt_FromSize_t
-PyAPI_FUNC(struct _object *) PyInt_FromSize_t(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyInt_FromSize_t(size_t arg0);
 #define PyInt_FromSsize_t PyPyInt_FromSsize_t
 PyAPI_FUNC(struct _object *) PyInt_FromSsize_t(Signed arg0);
 #define PyInt_FromString PyPyInt_FromString
@@ -415,13 +415,13 @@ PyAPI_FUNC(Signed) PyLong_AsLongLongAndOverflow(struct _object *arg0, int *arg1)
 #define PyLong_AsSsize_t PyPyLong_AsSsize_t
 PyAPI_FUNC(Signed) PyLong_AsSsize_t(struct _object *arg0);
 #define PyLong_AsUnsignedLong PyPyLong_AsUnsignedLong
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLong(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLong PyPyLong_AsUnsignedLongLong
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLong(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLongMask PyPyLong_AsUnsignedLongLongMask
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
 #define PyLong_AsUnsignedLongMask PyPyLong_AsUnsignedLongMask
-PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongMask(struct _object *arg0);
+PyAPI_FUNC(size_t) PyLong_AsUnsignedLongMask(struct _object *arg0);
 #define PyLong_AsVoidPtr PyPyLong_AsVoidPtr
 PyAPI_FUNC(void *) PyLong_AsVoidPtr(struct _object *arg0);
 #define PyLong_FromDouble PyPyLong_FromDouble
@@ -431,7 +431,7 @@ PyAPI_FUNC(struct _object *) PyLong_FromLong(Signed arg0);
 #define PyLong_FromLongLong PyPyLong_FromLongLong
 PyAPI_FUNC(struct _object *) PyLong_FromLongLong(Signed arg0);
 #define PyLong_FromSize_t PyPyLong_FromSize_t
-PyAPI_FUNC(struct _object *) PyLong_FromSize_t(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromSize_t(size_t arg0);
 #define PyLong_FromSsize_t PyPyLong_FromSsize_t
 PyAPI_FUNC(struct _object *) PyLong_FromSsize_t(Signed arg0);
 #define PyLong_FromString PyPyLong_FromString
@@ -439,9 +439,9 @@ PyAPI_FUNC(struct _object *) PyLong_FromString(const char *arg0, char **arg1, in
 #define PyLong_FromUnicode PyPyLong_FromUnicode
 PyAPI_FUNC(struct _object *) PyLong_FromUnicode(wchar_t *arg0, Signed arg1, int arg2);
 #define PyLong_FromUnsignedLong PyPyLong_FromUnsignedLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(size_t arg0);
 #define PyLong_FromUnsignedLongLong PyPyLong_FromUnsignedLongLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(Unsigned arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(size_t arg0);
 #define PyLong_FromVoidPtr PyPyLong_FromVoidPtr
 PyAPI_FUNC(struct _object *) PyLong_FromVoidPtr(void *arg0);
 #define PyMapping_Check PyPyMapping_Check
@@ -639,13 +639,13 @@ PyAPI_FUNC(int) PyObject_IsSubclass(struct _object *arg0, struct _object *arg1);
 #define PyObject_IsTrue PyPyObject_IsTrue
 PyAPI_FUNC(int) PyObject_IsTrue(struct _object *arg0);
 #define PyObject_Malloc PyPyObject_Malloc
-PyAPI_FUNC(void *) PyObject_Malloc(Unsigned arg0);
+PyAPI_FUNC(void *) PyObject_Malloc(size_t arg0);
 #define PyObject_Not PyPyObject_Not
 PyAPI_FUNC(int) PyObject_Not(struct _object *arg0);
 #define PyObject_Print PyPyObject_Print
 PyAPI_FUNC(int) PyObject_Print(struct _object *arg0, FILE *arg1, int arg2);
 #define PyObject_Realloc PyPyObject_Realloc
-PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, Unsigned arg1);
+PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, size_t arg1);
 #define PyObject_Repr PyPyObject_Repr
 PyAPI_FUNC(struct _object *) PyObject_Repr(struct _object *arg0);
 #define PyObject_RichCompare PyPyObject_RichCompare
@@ -801,7 +801,7 @@ PyAPI_FUNC(struct _object *) PyThreadState_GetDict(void);
 #define PyThreadState_New PyPyThreadState_New
 PyAPI_FUNC(PyThreadState *) PyThreadState_New(PyInterpreterState *arg0);
 #define PyThreadState_SetAsyncExc PyPyThreadState_SetAsyncExc
-PyAPI_FUNC(int) PyThreadState_SetAsyncExc(Unsigned arg0, struct _object *arg1);
+PyAPI_FUNC(int) PyThreadState_SetAsyncExc(size_t arg0, struct _object *arg1);
 #define PyThreadState_Swap PyPyThreadState_Swap
 PyAPI_FUNC(PyThreadState *) PyThreadState_Swap(PyThreadState *arg0);
 #define PyTime_Check PyPyTime_Check
@@ -1039,11 +1039,11 @@ PyAPI_FUNC(int) _PyImport_ReleaseLock(void);
 #define _PyInstance_Lookup _PyPyInstance_Lookup
 PyAPI_FUNC(struct _object *) _PyInstance_Lookup(struct _object *arg0, struct _object *arg1);
 #define _PyLong_AsByteArrayO _PyPyLong_AsByteArrayO
-PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, Unsigned arg2, int arg3, int arg4);
+PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, size_t arg2, int arg3, int arg4);
 #define _PyLong_FromByteArray _PyPyLong_FromByteArray
-PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, Unsigned arg1, int arg2, int arg3);
+PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, size_t arg1, int arg2, int arg3);
 #define _PyLong_NumBits _PyPyLong_NumBits
-PyAPI_FUNC(Unsigned) _PyLong_NumBits(struct _object *arg0);
+PyAPI_FUNC(size_t) _PyLong_NumBits(struct _object *arg0);
 #define _PyLong_Sign _PyPyLong_Sign
 PyAPI_FUNC(int) _PyLong_Sign(struct _object *arg0);
 #define _PyObject_GetDictPtr _PyPyObject_GetDictPtr
